@@ -3,6 +3,7 @@ import numpy as np
 from .net import Net
 from time import time
 import json, zipfile
+from io import BytesIO
 
 def read_net(path):
     net = Net()
@@ -11,7 +12,8 @@ def read_net(path):
             path = os.path.split(path)[1]
             body = json.loads(f.read(path+'.json'))
             lay, flw = body['layers'], body['flow']
-            weights = np.load(f.open(path+'.npy'))
+            buf = BytesIO(f.read(path+'.npy'))
+            weights = np.load(buf)
     else:
         with open(path+'.json') as f:
             body = json.load(f)
